@@ -322,7 +322,7 @@ class Tensor2Field(DataFieldBase):
 
     @fill_in_docstring
     def divergence(
-        self, bc: "BoundariesData", out: Optional[VectorField] = None, **kwargs
+        self, bc: Optional[BoundariesData], out: Optional[VectorField] = None, **kwargs
     ) -> VectorField:
         r"""apply tensor divergence and return result as a field
 
@@ -335,7 +335,7 @@ class Tensor2Field(DataFieldBase):
         Args:
             bc:
                 The boundary conditions applied to the field.
-                {ARG_BOUNDARIES}
+                {ARG_BOUNDARIES_OPTIONAL}
             out (VectorField, optional):
                 Optional scalar field to which the  result is written.
             label (str, optional):
