@@ -454,14 +454,14 @@ class VectorField(DataFieldBase):
 
     @fill_in_docstring
     def divergence(
-        self, bc: "BoundariesData", out: Optional[ScalarField] = None, **kwargs
+        self, bc: Optional[BoundariesData], out: Optional[ScalarField] = None, **kwargs
     ) -> ScalarField:
         """apply divergence operator and return result as a field
 
         Args:
             bc:
                 The boundary conditions applied to the field.
-                {ARG_BOUNDARIES}
+                {ARG_BOUNDARIES_OPTIONAL}
             out (ScalarField, optional):
                 Optional scalar field to which the  result is written.
             label (str, optional):
@@ -474,7 +474,10 @@ class VectorField(DataFieldBase):
 
     @fill_in_docstring
     def gradient(
-        self, bc: "BoundariesData", out: Optional["Tensor2Field"] = None, **kwargs
+        self,
+        bc: Optional[BoundariesData],
+        out: Optional["Tensor2Field"] = None,
+        **kwargs,
     ) -> "Tensor2Field":
         r"""apply vector gradient operator and return result as a field
 
@@ -485,7 +488,7 @@ class VectorField(DataFieldBase):
         Args:
             bc:
                 The boundary conditions applied to the field.
-                {ARG_BOUNDARIES}
+                {ARG_BOUNDARIES_OPTIONAL}
             out (VectorField, optional):
                 Optional vector field to which the result is written.
             label (str, optional):
@@ -498,7 +501,7 @@ class VectorField(DataFieldBase):
 
     @fill_in_docstring
     def laplace(
-        self, bc: "BoundariesData", out: Optional[VectorField] = None, **kwargs
+        self, bc: Optional[BoundariesData], out: Optional[VectorField] = None, **kwargs
     ) -> VectorField:
         r"""apply vector Laplace operator and return result as a field
 
@@ -513,7 +516,7 @@ class VectorField(DataFieldBase):
         Args:
             bc:
                 The boundary conditions applied to the field.
-                {ARG_BOUNDARIES}
+                {ARG_BOUNDARIES_OPTIONAL}
             out (VectorField, optional):
                 Optional vector field to which the  result is written.
             label (str, optional):
