@@ -104,13 +104,12 @@ class KPZInterfacePDE(PDEBase):
             the time to obtained an instance of :class:`~numpy.ndarray` giving
             the evolution rate.
         """
-        shape = state.grid.shape
-        arr_type = nb.typeof(np.empty(shape, dtype=state.data.dtype))
+        arr_type = nb.typeof(state.data)
         signature = arr_type(arr_type, nb.double)
 
         nu_value, lambda_value = self.nu, self.lmbda
-        laplace = state.grid.get_operator("laplace", bc=self.bc)
-        gradient_squared = state.grid.get_operator("gradient_squared", bc=self.bc)
+        laplace = state.grid.make_operator("laplace", bc=self.bc)
+        gradient_squared = state.grid.make_operator("gradient_squared", bc=self.bc)
 
         @jit(signature)
         def pde_rhs(state_data: np.ndarray, t: float):
