@@ -15,6 +15,7 @@ def solve_poisson_equation(
     rhs: ScalarField,
     bc: "BoundariesData",
     label: str = "Solution to Poisson's equation",
+    **kwargs,
 ) -> ScalarField:
     r"""Solve Laplace's equation on a given grid
 
@@ -53,10 +54,17 @@ def solve_poisson_equation(
         :class:`~pde.fields.scalar.ScalarField`: The field :math:`u` that solves
         the equation. This field will be defined on the same grid as `rhs`.
     """
+    # get the operator information
+    operator = rhs.grid._get_operator_info("poisson_solver")
+    # get the boundary conditions
+    bcs = rhs.grid.get_boundary_conditions(bc)
+    # get the actual solver
+    solver = operator.factory(bcs=bcs, **kwargs)
+
     # solve the poisson problem
-    solve_poisson = rhs.grid.get_operator("poisson_solver", bc=bc)
+    result = ScalarField(rhs.grid, label=label)
     try:
-        result = solve_poisson(rhs.data)
+        solver(rhs.data, result.data)
     except RuntimeError:
         magnitude = rhs.magnitude
         if magnitude > 1e-10:
@@ -68,7 +76,7 @@ def solve_poisson_equation(
         else:
             raise  # another error occurred
 
-    return ScalarField(rhs.grid, result, label=label)
+    return result
 
 
 @fill_in_docstring
@@ -93,4 +101,5 @@ def solve_laplace_equation(
         :class:`~pde.fields.scalar.ScalarField`: The field that solves the
         equation. This field will be defined on the given `grid`.
     """
-    return solve_poisson_equation(ScalarField(grid), bc=bc, label=label)
+    rhs = ScalarField(grid, data=0)
+    return solve_poisson_equation(rhs, bc=bc, label=label)
